@@ -54,6 +54,7 @@ import Data.Traversable (Traversable, )
 import Data.Foldable (Foldable, )
 -}
 import Data.Monoid(Monoid, mappend, mempty, )
+import Data.Semigroup (Semigroup((<>)), )
 import Data.Function (const, (.), ($), )
 import Data.Maybe (Maybe(Just, Nothing), maybe, )
 
@@ -201,6 +202,10 @@ maybeAbort (Exceptional ea a) eb =
 instance (NFData e, NFData a) => NFData (Exceptional e a) where
    rnf (Exceptional e a) = rnf (e, a)
 
+instance Monoid a => Semigroup (Exceptional e a) where
+   Exceptional ea a <> Exceptional eb b =
+      Exceptional (mplus ea eb) (mappend a (maybe b (const mempty) ea))
+
 {- |
 'mappend' must be strict in order to fulfill the Monoid laws
 @mappend mempty a = a@ and @mappend a mempty = a@ for @a=undefined@.
@@ -208,8 +213,7 @@ instance (NFData e, NFData a) => NFData (Exceptional e a) where
 instance Monoid a => Monoid (Exceptional e a) where
    mempty = pure mempty
 --   mappend = append
-   mappend (Exceptional ea a) (Exceptional eb b) =
-      Exceptional (mplus ea eb) (mappend a (maybe b (const mempty) ea))
+   mappend = (<>)
 
 
 {- | construct Exceptional constructor lazily -}
@@ -372,12 +376,15 @@ instance Functor m => Functor (ExceptionalT e m) where
    fmap f (ExceptionalT x) =
       ExceptionalT (fmap (fmap f) x)
 
-instance (Monad m, Monoid a) => Monoid (ExceptionalT e m a) where
-   mempty = ExceptionalT $ return mempty
-   mappend x y =
+instance (Monad m, Monoid a) => Semigroup (ExceptionalT e m a) where
+   x <> y =
       ExceptionalT $
       appendM (runExceptionalT x) (runExceptionalT y)
 
+instance (Monad m, Monoid a) => Monoid (ExceptionalT e m a) where
+   mempty = ExceptionalT $ return mempty
+   mappend = (<>)
+
 {-
 instance Applicative m => Applicative (ExceptionalT e m) where
    pure = ExceptionalT . pure . pure
